@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -205,7 +213,6 @@ public class FormatData_brx extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_hmv = "a h:mm v";
         final String metaValue_generic_DateFormatItem_Gy = "Gy";
         final String metaValue_generic_DateFormatItem_Bhms = "B नि h:mm:ss";
-        final String metaValue_generic_DateFormatItem_hmsv = "a नि h:mm:ss v";
         final String metaValue_generic_DateFormatItem_yMMMd = "d MMM y";
         final String metaValue_generic_DateFormatItem_yQQQ = "QQQ y";
         final String metaValue_generic_DateFormatItem_yMMM = "MMM y";
@@ -237,7 +244,6 @@ public class FormatData_brx extends ListResourceBundle {
             "d MMM y, GGGG",
             "d/M/yy G",
         };
-        final String metaValue_buddhist_DateFormatItem_MMMMd = "MMMM d";
         final String metaValue_calendarname_gregorian = "ग्रेग’रियान फान्जामुथि";
         final String[] metaValue_ListPatterns_standard = new String[] {
             "",
@@ -270,7 +276,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "generic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
             { "generic.DateFormatItem.yyyyMMMEd", "d MMM y, G E" },
-            { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "generic.DateFormatItem.GyMMMd", "d MMM, G y" },
             { "generic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "generic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
@@ -282,6 +287,7 @@ public class FormatData_brx extends ListResourceBundle {
             { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "generic.DateFormatItem.yyyyMMM", "G MMM y" },
             { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "generic.DateFormatItem.MMMMd", "d MMMM" },
             { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -364,7 +370,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -403,7 +408,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "buddhist.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "buddhist.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "buddhist.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "buddhist.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -411,7 +415,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "buddhist.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "buddhist.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -450,7 +453,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "japanese.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "japanese.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "japanese.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -458,7 +460,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "japanese.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -490,7 +491,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "roc.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "roc.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "roc.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "roc.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -498,7 +498,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "roc.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "roc.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -527,7 +526,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -535,7 +533,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -555,7 +552,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic-civil.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic-civil.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-civil.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-civil.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -563,7 +559,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-civil.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -583,7 +578,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
             { "islamic-umalqura.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic-umalqura.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
             { "islamic-umalqura.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-umalqura.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -591,7 +585,6 @@ public class FormatData_brx extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
             { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
             { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
@@ -638,6 +631,32 @@ public class FormatData_brx extends ListResourceBundle {
                     "¤#,##0.00;(¤#,##0.00)",
                 }
             },
+            { "deva.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "०",
+                    "#",
+                    "-",
+                    "E",
+                    "‰",
+                    "∞",
+                    "NaN",
+                    "",
+                    "",
+                    "-－﹣‐‑‒–−⁻₋➖",
+                }
+            },
+            { "deva.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "¤ #,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
