@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -236,6 +244,7 @@ public class FormatData_da extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_MEd = "E d.M";
         final String metaValue_generic_DateFormatItem_MMMEd = "E d. MMM";
         final String metaValue_generic_DateFormatItem_yMM = "MM.y";
+        final String metaValue_generic_DateFormatItem_GyMEd = "E d/M/y G";
         final String metaValue_generic_DateFormatItem_d = "d.";
         final String metaValue_generic_DateFormatItem_Hmsv = "HH.mm.ss v";
         final String metaValue_generic_DateFormatItem_GyMd = "d.M.y GGGGG";
@@ -247,6 +256,7 @@ public class FormatData_da extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_yMMMM = "MMMM y";
         final String metaValue_generic_DateFormatItem_MMMMW = "W. 'uge' 'i' MMMM";
         final String metaValue_generic_DateFormatItem_yQQQQ = "QQQQ y";
+        final String metaValue_generic_DateFormatItem_GyM = "M/y G";
         final String[] metaValue_java_time_generic_DatePatterns = new String[] {
             "EEEE d. MMMM y G",
             "d. MMMM y G",
@@ -259,7 +269,6 @@ public class FormatData_da extends ListResourceBundle {
             "d. MMM y GGGG",
             "d.M.y",
         };
-        final String metaValue_buddhist_DateFormatItem_h = "h a";
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
             "før R.O.C.",
             "Minguo",
@@ -330,6 +339,7 @@ public class FormatData_da extends ListResourceBundle {
             { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "generic.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.yyyyQQQ", "QQQ y G" },
             { "generic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
             { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
@@ -346,6 +356,7 @@ public class FormatData_da extends ListResourceBundle {
             { "generic.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "generic.DateFormatItem.yyyy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_Gy },
+            { "generic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "MonthNames", metaValue_MonthNames },
             { "standalone.MonthNames", metaValue_MonthNames },
@@ -430,6 +441,7 @@ public class FormatData_da extends ListResourceBundle {
             { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "DateFormatItem.d", metaValue_generic_DateFormatItem_d },
             { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
@@ -442,6 +454,7 @@ public class FormatData_da extends ListResourceBundle {
             { "DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -487,8 +500,8 @@ public class FormatData_da extends ListResourceBundle {
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "buddhist.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "buddhist.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "buddhist.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "buddhist.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -500,6 +513,7 @@ public class FormatData_da extends ListResourceBundle {
             { "buddhist.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "buddhist.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "buddhist.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "buddhist.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -559,8 +573,8 @@ public class FormatData_da extends ListResourceBundle {
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "japanese.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "japanese.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "japanese.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "japanese.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -572,6 +586,7 @@ public class FormatData_da extends ListResourceBundle {
             { "japanese.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "japanese.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "japanese.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "japanese.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "roc.MonthNames", metaValue_MonthNames },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -623,8 +638,8 @@ public class FormatData_da extends ListResourceBundle {
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "roc.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "roc.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "roc.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "roc.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -636,6 +651,7 @@ public class FormatData_da extends ListResourceBundle {
             { "roc.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "roc.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "roc.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic.MonthNames",
                 new String[] {
@@ -695,8 +711,8 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -708,6 +724,7 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-civil.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
@@ -741,8 +758,8 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic-civil.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "islamic-civil.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-civil.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic-civil.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -754,6 +771,7 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic-civil.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic-civil.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-civil.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-umalqura.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
@@ -787,8 +805,8 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
             { "islamic-umalqura.DateFormatItem.yMM", metaValue_generic_DateFormatItem_yMM },
+            { "islamic-umalqura.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-umalqura.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "islamic-umalqura.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
             { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -800,6 +818,7 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic-umalqura.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic-umalqura.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "calendarname.islamic-civil", "verdslig hijri-kalender" },
             { "calendarname.islamic", "hijri-kalender" },
